@@ -45,6 +45,8 @@ code from qwriter:
 
 #include "textproc.h"
 
+
+
 #include <QSettings>
 #include <QLabel>
 #include <QPainter>
@@ -55,6 +57,7 @@ code from qwriter:
 #include <QMimeData>
 
 #include <bitset>
+#include <algorithm>
 
 #if QT_VERSION >= 0x050000
 
@@ -68,6 +71,7 @@ QSettings *settings;
 QMenu *current_files_menu;
 
 bool b_recent_off;
+bool b_destroying_all;
 
 void CDocument::update_status()
 {
@@ -77,9 +81,10 @@ void CDocument::update_status()
       return;
      }
 
-  QTextBlock block = textEdit->document()->begin();
-  int cursor_offset = textEdit->textCursor().position();
-  
+//  QTextBlock block = textEdit->document()->begin();
+//  int cursor_offset = textEdit->textCursor().position();
+ 
+ /* 
   int off = 0;
   int y = 1;
 
@@ -91,6 +96,9 @@ void CDocument::update_status()
         }
 
   int x = cursor_offset - off + 1;
+*/
+  int x = textEdit->textCursor().position() - textEdit->textCursor().block().position() + 1;
+  int y = textEdit->textCursor().block().blockNumber() + 1;
 
   holder->l_status_bar->setText (QString ("%1:%2 %3").arg (
                                  QString::number (y)).arg (
@@ -196,7 +204,7 @@ bool CDocument::save_with_name (const QString &fileName, const QString &codec)
 
   holder->log->log (tr ("%1 is saved").arg (file_name));
 
-  update_title();
+  update_title (settings->value ("full_path_at_window_title", 1).toBool());
   update_status();
 
   textEdit->document()->setModified (false);
@@ -328,6 +336,8 @@ void document_holder::reload_recent_list (void)
 
 document_holder::~document_holder()
 {
+  b_destroying_all = true;
+
   while (! list.isEmpty())
         delete list.takeFirst();
 
@@ -348,7 +358,7 @@ CDocument* document_holder::create_new()
   tab_widget->setCurrentIndex (tab_widget->indexOf (doc->tab_page));
   apply_settings_single (doc);
 
-  doc->update_title();
+  doc->update_title (settings->value ("full_path_at_window_title", 1).toBool());
   doc->update_status();
   
   update_current_files_menu();
@@ -396,7 +406,7 @@ CDocument* document_holder::open_file (const QString &fileName, const QString &c
   CDocument *doc = create_new();
   doc->open_file (fileName, codec);
   doc->update_status();
-  doc->update_title();
+  doc->update_title (settings->value ("full_path_at_window_title", 1).toBool());
 
   tab_widget->setCurrentIndex (tab_widget->indexOf (doc->tab_page));
   
@@ -660,12 +670,7 @@ void document_holder::apply_settings_single (CDocument *d)
   else
      d->textEdit->document()->setDefaultTextOption (QTextOption (Qt::AlignLeft));
     
-    /*
-  if (settings->value ("word_wrap", "2").toInt() == 2)
-     d->textEdit->setLineWrapMode (QPlainTextEdit::WidgetWidth);
-  else
-      d->textEdit->setLineWrapMode (QPlainTextEdit::NoWrap);
-*/
+ 
   d->textEdit->tab_sp_width = settings->value ("tab_sp_width", 8).toInt();
   d->textEdit->spaces_instead_of_tabs = settings->value ("spaces_instead_of_tabs", true).toBool();
 
@@ -926,6 +931,8 @@ void CTEAEdit::setup_brace_width()
 
 CTEAEdit::CTEAEdit (QWidget *parent): QPlainTextEdit (parent)
 {
+  rect_sel_reset();
+
   highlightCurrentLine = false;
   setup_brace_width();
   
@@ -1621,6 +1628,7 @@ void CDocument::insert_image (const QString &full_path)
   textEdit->textCursor().insertText (get_insert_image (file_name, full_path, markup_mode));
 }
 
+
 void CTEAEdit::calc_auto_indent()
 {
   QTextCursor cur = textCursor();
@@ -1739,6 +1747,7 @@ void CTEAEdit::un_indent()
   setTextCursor (cur);
 }
 
+
 #define SK_A 38
 #define SK_D 40
 #define SK_W 25
@@ -1945,8 +1954,8 @@ void CTEAEdit::resizeEvent (QResizeEvent *e)
 void CTEAEdit::braceHighlight()
 {
   extraSelections.clear();
-  setExtraSelections(extraSelections);
-  selection.format.setBackground(brackets_color);
+  setExtraSelections (extraSelections);
+  selection.format.setBackground (brackets_color);
 
   QTextDocument *doc = document();
   QTextCursor cursor = textCursor();
@@ -2075,6 +2084,118 @@ void CTEAEdit::braceHighlight()
 }
 
 
+void CTEAEdit::update_rect_sel()
+{
+  qDebug() << "CTEAEdit::update_rect_sel()  -1";
+ 
+  if (rect_sel_start.y() == -1 || rect_sel_end.y() == -1)
+     return; 
+ 
+  QTextEdit::ExtraSelection rect_selection;
+
+  extraSelections.clear();
+  
+  
+  int y1 = std::min (rect_sel_start.y(), rect_sel_end.y());
+  int y2 = std::max (rect_sel_start.y(), rect_sel_end.y());
+  int ydiff = y2 - y1;
+   
+  
+  int x1 = std::min (rect_sel_start.x(), rect_sel_end.x());
+  int x2 = std::max (rect_sel_start.x(), rect_sel_end.x());
+  int xdiff = x2 - x1;
+ 
+
+  QTextCursor cursor = textCursor();
+  
+  cursor.movePosition (QTextCursor::Start, QTextCursor::MoveAnchor);
+  cursor.movePosition (QTextCursor::NextBlock, QTextCursor::MoveAnchor, y1);
+  
+  for (int y = y1; y <= y2; y++)
+      {
+//       qDebug() << "y:" << y;
+       cursor.movePosition (QTextCursor::Right, QTextCursor::MoveAnchor, x1);
+              
+       int sel_len = xdiff;
+       
+       QTextBlock b = document()->findBlockByNumber (y); 
+       
+       if ((b.text().length() - x1) < xdiff)
+          sel_len = b.text().length() - x1;
+          
+       cursor.movePosition (QTextCursor::Right, QTextCursor::KeepAnchor, sel_len);
+              
+       rect_selection.cursor = cursor;
+       rect_selection.format.setBackground (brackets_color);
+       extraSelections.append (rect_selection);
+  
+       cursor.movePosition (QTextCursor::NextBlock, QTextCursor::MoveAnchor);
+      }
+
+  setExtraSelections (extraSelections);
+ /*
+  qDebug() << "ydiff: " << ydiff;
+  qDebug() << "y1:" << y1;
+  qDebug() << "y2:" << y2;
+  qDebug() << "x1:" << x1;
+  qDebug() << "x2:" << x2;
+  */
+  qDebug() << get_rect_sel();
+  
+}
+  
+  
+void CTEAEdit::rect_sel_replace (const QString &s)
+{
+/*
+
+1. Определить с какой строки начинаем вставку
+2. Определить как вставляемый текст перекрывает старый. Если строк в старом меньше (или конец файла), 
+добавляем в выходной буфер строки.
+3. Составляем выходной буфер из строк старого и нового.
+4. Заменяем старый текст на выходной буфер.
+
+*/
+
+  int y = textCursor().block().blockNumber();
+  int x = textCursor().position() - textCursor().block().position();
+ 
+  int y1 = std::min (rect_sel_start.y(), rect_sel_end.y());
+  int y2 = std::max (rect_sel_start.y(), rect_sel_end.y());
+  int ydiff = y2 - y1;
+   
+  
+  int x1 = std::min (rect_sel_start.x(), rect_sel_end.x());
+  int x2 = std::max (rect_sel_start.x(), rect_sel_end.x());
+  int xdiff = x2 - x1;
+  
+  int how_many_copy_from_source = ydiff;
+  
+  int lines_to_end = blockCount() - y;
+  
+  if (ydiff > lines_to_end)
+     how_many_copy_from_source = lines_to_end;
+     
+  QStringList sl_source;
+  
+  
+  for (int line = y1; y <= y2; y++)
+      {
+       //int sel_len = xdiff;
+       
+       QTextBlock b = document()->findBlockByNumber (line); 
+       
+       //if ((b.text().length() - x1) < xdiff)
+         // sel_len = b.text().length() - x1;
+          
+       sl_source.append (b.text());   
+          
+      }  
+  
+  
+}
+    
+
 bool CTEAEdit::canInsertFromMimeData (const QMimeData *source)
 {
 //  if (source->hasFormat ("text/uri-list"))
@@ -2190,6 +2311,49 @@ void document_holder::update_current_files_menu()
 }
 
 
+void CTEAEdit::rect_sel_reset()
+{
+  rect_sel_start.setX (-1);
+  rect_sel_start.setY (-1);
+  rect_sel_end.setX (-1);
+  rect_sel_end.setY (-1);
+}
+
+
+QString CTEAEdit::get_rect_sel()
+{
+  QString result;
+
+  int y1 = std::min (rect_sel_start.y(), rect_sel_end.y());
+  int y2 = std::max (rect_sel_start.y(), rect_sel_end.y());
+  int ydiff = y2 - y1;
+  
+  int x1 = std::min (rect_sel_start.x(), rect_sel_end.x());
+  int x2 = std::max (rect_sel_start.x(), rect_sel_end.x());
+  int xdiff = x2 - x1;
+ 
+
+  for (int y = y1; y <= y2; y++)
+      {
+//       qDebug() << "y:" << y;
+              
+       int sel_len = xdiff;
+       
+       QTextBlock b = document()->findBlockByNumber (y); 
+       
+       if ((b.text().length() - x1) < xdiff)
+          sel_len = b.text().length() - x1;
+          
+       QString t = b.text();   
+       //qDebug() << t;
+       result += t.mid (x1, xdiff);
+       if (y != y2)
+          result += '\n';   
+      }
+
+  return result;
+}
+
 
 /*
  * 
