@@ -42,6 +42,8 @@ code from qwriter:
 #include "todo.h"
 
 
+#include <QPoint>
+
 #include <QStatusBar>
 #include <QMainWindow>
 #include <QTabWidget>
@@ -65,13 +67,21 @@ class CTEAEdit: public QPlainTextEdit
 {
   Q_OBJECT
 
-private:
-    
+   
+
+public:
+
   QString indent_val;  
   QList <QTextEdit::ExtraSelection> extraSelections;
   QTextEdit::ExtraSelection selection;
 
-public:
+  
+  //rect selection
+
+  QPoint rect_sel_start;
+  QPoint rect_sel_end;
+ 
+ 
 
   CDocument *doc;
 
@@ -114,6 +124,13 @@ public:
   void calc_auto_indent();
   void setup_brace_width();
 
+  void rect_sel_reset();
+  void rect_sel_replace (const QString &s);
+  
+  void update_rect_sel();
+  
+  QString get_rect_sel();
+
   void braceHighlight();
   
   void lineNumberAreaPaintEvent(QPaintEvent *event);
