@@ -1,5 +1,3 @@
-// "single_application.h"
-
 /*
  * taken from http://www.qtcentre.org/wiki/index.php?title=SingleApplication
  * LGPL'ed source code
@@ -7,7 +5,6 @@
  * 
  */
 
-
 #ifndef SINGLE_APPLICATION_H
 #define SINGLE_APPLICATION_H
 
@@ -31,6 +28,8 @@ public:
         bool isRunning();
         bool sendMessage(const QString &message);
 
+        static int cursorFlashTime() {return 0;}; 
+
 public slots:
         void receiveMessage();
 
