@@ -38,6 +38,8 @@ some code is taken from Scribus::util.cpp:
 #include <QString>
 #include <QMap>
 
+//#include <bitset>
+
 #include "textproc.h"
 #include "utils.h"
 
@@ -348,13 +350,41 @@ int romanToDecimal (const char *roman)
 
 QString qstringlist_process (const QString &s, const QString &params, int mode)
 {
-  QStringList sl = s.split (QChar::ParagraphSeparator);
+  QStringList sl;
   QStringList l;
   QString result;
+  
+  if (mode != QSTRL_PROC_FLT_WITH_SORTCASECARE_SEP && mode != QSTRL_PROC_LIST_FLIP_SEP)
+     sl = s.split (QChar::ParagraphSeparator);
 
   switch (mode)
          {
+          case QSTRL_PROC_FLT_WITH_SORTCASECARE_SEP:
+                                                    {
+                                                     if (s.indexOf (params) == -1)
+                                                        return s;
+                                                        
+                                                     QStringList sl = s.split (params);
+                                                     sl.sort();
+                                                     result = sl.join (params);
+                                                     return result;
+                                                    };
+                                                    
+          case QSTRL_PROC_LIST_FLIP_SEP:  {
+                                           if (s.indexOf (params) == -1)
+                                              return s;
+        
+                                           QStringList sl = s.split (params);
+                                           sl.sort();
+                                                     
+                                           foreach (QString t, sl)
+                                           l.prepend (t);
 
+                                           result = l.join (params);
+                                           return result;
+                                          };
+                                                                                                   
+         
           case QSTRL_PROC_FLT_WITH_SORTNOCASECARE:
                                                  {
                                                   QMap <QString, QString> map;
@@ -471,6 +501,13 @@ QString int_to_binary (int n)
   return result;
 }
 
+/*
+QString int_to_binary (int n)
+{
+  std::bitset<sizeof (int)> bt (n);  
+  return QString::fromStdString (bt.to_string<char,std::string::traits_type,std::string::allocator_type>());
+}
+*/
 
 unsigned int bin_to_decimal (const QString &s)
 {
